==> open-cluster-management-observability-model-5.12.4-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/CacheConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CacheConfigBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigBuilder>{
  public CacheConfigBuilder() {
    this(false);
  }
  public CacheConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new CacheConfig(), validationEnabled);
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CacheConfig(), validationEnabled);
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig instance) {
    this(fluent, instance, false);
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConnectionLimit(instance.getConnectionLimit()); 
    fluent.withMaxItemSize(instance.getMaxItemSize()); 
    fluent.withMemoryLimitMb(instance.getMemoryLimitMb()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withResources(instance.getResources()); 
    this.validationEnabled = validationEnabled; 
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig instance) {
    this(instance,false);
  }
  public CacheConfigBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConnectionLimit(instance.getConnectionLimit()); 
    this.withMaxItemSize(instance.getMaxItemSize()); 
    this.withMemoryLimitMb(instance.getMemoryLimitMb()); 
    this.withReplicas(instance.getReplicas()); 
    this.withResources(instance.getResources()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.CacheConfig build() {
    CacheConfig buildable = new CacheConfig(fluent.getConnectionLimit(),fluent.getMaxItemSize(),fluent.getMemoryLimitMb(),fluent.getReplicas(),fluent.getResources());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CacheConfigBuilder that = (CacheConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-observability-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/CacheConfigBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CacheConfigBuilder extends CacheConfigFluentImpl<CacheConfigBuilder> implements VisitableBuilder<CacheConfig,CacheConfigBuilder>{
  public CacheConfigBuilder() {
    this(false);
  }
  public CacheConfigBuilder(Boolean validationEnabled) {
    this(new CacheConfig(), validationEnabled);
  }
  public CacheConfigBuilder(CacheConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public CacheConfigBuilder(CacheConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CacheConfig(), validationEnabled);
  }
  public CacheConfigBuilder(CacheConfigFluent<?> fluent,CacheConfig instance) {
    this(fluent, instance, false);
  }
  public CacheConfigBuilder(CacheConfigFluent<?> fluent,CacheConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConnectionLimit(instance.getConnectionLimit()); 
    fluent.withMaxItemSize(instance.getMaxItemSize()); 
    fluent.withMemoryLimitMb(instance.getMemoryLimitMb()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withResources(instance.getResources()); 
    this.validationEnabled = validationEnabled; 
  }
  public CacheConfigBuilder(CacheConfig instance) {
    this(instance,false);
  }
  public CacheConfigBuilder(CacheConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConnectionLimit(instance.getConnectionLimit()); 
    this.withMaxItemSize(instance.getMaxItemSize()); 
    this.withMemoryLimitMb(instance.getMemoryLimitMb()); 
    this.withReplicas(instance.getReplicas()); 
    this.withResources(instance.getResources()); 
    this.validationEnabled = validationEnabled; 
  }
  CacheConfigFluent<?> fluent;
  Boolean validationEnabled;
  public CacheConfig build() {
    CacheConfig buildable = new CacheConfig(fluent.getConnectionLimit(),fluent.getMaxItemSize(),fluent.getMemoryLimitMb(),fluent.getReplicas(),fluent.getResources());
    return buildable;
  }
  
}
